Enum Frxth
#[repr(u8)]pub enum Frxth {
Half = 0,
Quarter = 1,
}Variants
Half = 0
RXNE event is generated if the FIFO level is greater than or equal to 1/2 (16-bit)
Quarter = 1
RXNE event is generated if the FIFO level is greater than or equal to 1/4 (8-bit)
Implementations